pub enum ContentPart {
Text {
text: String,
},
Reasoning {
text: String,
},
FileData {
file_uri: String,
mime_type: Option<String>,
},
InlineData {
mime_type: String,
data: ByteBufB64,
},
ToolCall {
name: String,
args: Json,
call_id: Option<String>,
},
ToolOutput {
name: String,
output: Json,
is_error: Option<bool>,
call_id: Option<String>,
remote_id: Option<Principal>,
},
Action {
name: String,
payload: Json,
recipients: Option<Vec<Principal>>,
signature: Option<ByteBufB64>,
},
Any(Json),
}Expand description
A single content item inside a chat message.
The enum supports Anda’s normalized content types while preserving unknown
provider-specific JSON payloads in ContentPart::Any.
Variants
Text
Visible text content.
Reasoning
Provider reasoning or thinking text.
FileData
File content referenced by URI.
InlineData
Inline binary data with an explicit MIME type.
Fields
data: ByteBufB64Base64-encoded binary payload.
ToolCall
Tool call requested by a model.
Fields
ToolOutput
Tool output returned to a model.
Fields
Action
Signed action payload emitted by an agent.
Fields
signature: Option<ByteBufB64>Optional signature over the action payload.
Any(Json)
Provider-specific content part preserved as raw JSON.
Implementations
Sourceimpl ContentPart
impl ContentPart
Sourcepub fn any_from<T>(ty: &str, val: T) -> Selfwhere
T: Serialize,
pub fn any_from<T>(ty: &str, val: T) -> Selfwhere
T: Serialize,
Creates a content part of type Any with the given type tag and value.
The type tag is only added when val serializes to a JSON object.
Sourcepub fn any_into<T>(self, ty: &str) -> Result<T, Box<Self>>where
T: DeserializeOwned,
pub fn any_into<T>(self, ty: &str) -> Result<T, Box<Self>>where
T: DeserializeOwned,
Attempts to convert this content part of type Any into the specified type if the type tag matches.
Sourcepub fn estimated_tokens(&self) -> usize
pub fn estimated_tokens(&self) -> usize
Estimates the number of tokens in this content part for usage accounting and pruning.