pub struct Message {
pub role: String,
pub content: Vec<ContentPart>,
pub name: Option<String>,
pub user: Option<Principal>,
pub timestamp: Option<u64>,
}Expand description
Chat message sent to or returned by an LLM provider.
Fields
role: StringMessage role: “system”, “user”, “assistant”, “tool”.
content: Vec<ContentPart>Message content parts.
name: Option<String>An optional name for the participant. Provides the model information to differentiate between participants of the same role. This field is not used by the model.
user: Option<Principal>The user ID of the message sender. This field is not used by the model.
timestamp: Option<u64>The timestamp of the message. This field is not used by the model.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn thoughts(&self) -> Option<String>
pub fn thoughts(&self) -> Option<String>
Returns all reasoning content parts joined with blank lines.
Sourcepub fn tool_calls(&self) -> Vec<ToolCall>
pub fn tool_calls(&self) -> Vec<ToolCall>
Extracts tool calls from this message.
Sourcepub fn prune_content(&mut self) -> usize
pub fn prune_content(&mut self) -> usize
Removes non-visible content parts and appends a short pruning notice.